kalasiris package
=================

Submodules
----------

kalasiris.Histogram module
--------------------------

.. automodule:: kalasiris.Histogram
    :members:
    :undoc-members:
    :show-inheritance:

kalasiris.PathSet module
------------------------

.. automodule:: kalasiris.PathSet
    :members:
    :undoc-members:
    :show-inheritance:

kalasiris.cubenormfile module
-----------------------------

.. automodule:: kalasiris.cubenormfile
    :members:
    :undoc-members:
    :show-inheritance:

kalasiris.k\_funcs module
-------------------------

.. automodule:: kalasiris.k_funcs
    :members:
    :undoc-members:
    :show-inheritance:

kalasiris.kalasiris module
--------------------------

.. automodule:: kalasiris.kalasiris
    :members:
    :undoc-members:
    :show-inheritance:

kalasiris.sweetened module
--------------------------

.. automodule:: kalasiris.sweetened
    :members:
    :undoc-members:
    :show-inheritance:

kalasiris.version module
------------------------

.. automodule:: kalasiris.version
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: kalasiris
    :members:
    :undoc-members:
    :show-inheritance:
